==> defi-services-lib-1.0.3.tar.gz: defi-services-lib-1.0.3/src/defi_services/lending_pools/lending_pools_info/bsc/valas_bsc.py <==
VALAS_BSC = {
    "address": "0xe29a55a6aeff5c8b1beede5bcf2f0cb3af8f91f5",
    "name": "Valas Lending Pool",
    "rewardToken": "0xb1ebdd56729940089ecc3ad0bbeeb12b6842ea6f",
    "multiFeeAddress": "0x685D3b02b9b0F044A3C01Dbb95408FC2eB15a3b3",
    "chefIncentiveAddress": '0xb7c1d99069a4eb582fc04e7e1124794000e7ecbf',
    "oracleAddress": "0x3436c4B4A27B793539844090e271591cbCb0303c",
    "type": "LENDING_POOL",
    "reservesList": {
        "0xbb4cdb9cbd36b01bd1cbaebf2de08d9173bc095c": {
            "createdAt": 1648498798,
            "tToken": "0xb11a912cd93dcffa8b609b4c021e89723ceb7fe8",
            "dToken": "0xe7cdc4e53915d50b74496847eeba7233cae85ce5",
            "id": "binancecoin",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.825,
            "label": "BNB"
        },
        "0xe9e7cea3dedca5984780bafc599bd69add087d56": {
            "createdAt": 1648498798,
            "tToken": "0xaed19dab3cd68e4267aec7b2479b1ed2144ad77f",
            "dToken": "0x24758d41e5aa89f79048076254a3d22927b2e0d4",
            "id": "binance-usd",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.85,
            "label": "BUSD"
        },
        "0x8ac76a51cc950d9822d68b83fe1ad97b32cd580d": {
            "createdAt": 1648498798,
            "tToken": "0xa6fdea1655910c504e974f7f1b520b74be21857b",
            "dToken": "0x8ef780a3e1c266af586315a9ada19dbfc3a1e45c",
            "id": "usd-coin",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.85,
            "label": "USDC"
        },
        "0x55d398326f99059ff775485246999027b3197955": {
            "createdAt": 1648499218,
            "tToken": "0x5f7f6cb266737b89f7af86b30f03ae94334b83e9",
            "dToken": "0x256b441313e10b7210a6239070c085446a507bd8",
            "ltv": 0.8,
            "id": "tether",
            "isNew": True,
            "liquidationThreshold": 0.85,
            "label": "USDT"
        },
        "0x1af3f329e8be154074d8769d1ffa4ee058b1dbc3": {
            "createdAt": 1648499218,
            "tToken": "0x2c85ebae81b7078cd656b2c6e2d58411cb41d91a",
            "dToken": "0x1cf681fc1df8aef478a675df40e62091b93e0aac",
            "ltv": 0.75,
            "id": "dai",
            "isNew": True,
            "liquidationThreshold": 0.8,
            "label": "DAI"
        },
        "0x0e09fabb73bd3ade0a17ecc321fd13a19e81ce82": {
            "createdAt": 1648499218,
            "tToken": "0xc37079a50611a742a018c39ba1c5ebdd89896334",
            "dToken": "0xc7c7bf1f28d29cea48f4aaaefb7e8c1fb43db200",
            "ltv": 0.5,
            "id": "pancakeswap-token",
            "isNew": True,
            "liquidationThreshold": 0.65,
            "label": "CAKE"
        },
        "0x2170ed0880ac9a755fd29b2688956bd959f933f8": {
            "createdAt": 1648499455,
            "tToken": "0x831f42c8a0892c1a5b7fa3e972b3ce3aa40d676e",
            "dToken": "0x9e06035740ab5ed9f48d8ff8b588056693b83e3a",
            "ltv": 0.8,
            "id": "ethereum",
            "isNew": True,
            "liquidationThreshold": 0.825,
            "label": "ETH"
        },
        "0x7130d2a12b9bcbfae4f2634d864a1ee1ce3ead9c": {
            "createdAt": 1648499455,
            "tToken": "0x204992f7fcbc4c0455d7fec5f712bedd98e7d6d6",
            "dToken": "0x5651565e4f544911f16f9a717d3aceccd29d1bda",
            "ltv": 0.7,
            "id": "binance-bitcoin",
            "isNew": True,
            "liquidationThreshold": 0.75,
            "label": "BTCB"
        },
        "0x14016e85a25aeb13065688cafb43044c2ef86784": {
            "createdAt": 1649678592,
            "tToken": "0xbb5dde96bad874e4ffe000b41fa5e98f0665a4bc",
            "dToken": "0xaeb0ae2b4cf427e6e3ebe14b6b92f8bf2d68dfd4",
            "ltv": 0.8,
            "id": "True-usd",
            "isNew": True,
            "liquidationThreshold": 0.825,
            "label": "TUSD"
        }
    },
    "lastUpdatedAt": 0,
    "intervalUpdate": 900,
    "url": "https://valasfinance.com/markets",
    "disabled": True
}

==> defi-services-lib-1.0.5.tar.gz: defi-services-lib-1.0.5/src/defi_services/lending_pools/lending_pools_info/bsc/valas_bsc.py <==
VALAS_BSC = {
    "address": "0xe29a55a6aeff5c8b1beede5bcf2f0cb3af8f91f5",
    "name": "Valas Lending Pool",
    "rewardToken": "0xb1ebdd56729940089ecc3ad0bbeeb12b6842ea6f",
    "multiFeeAddress": "0x685d3b02b9b0f044a3c01dbb95408fc2eb15a3b3",
    "chefIncentiveAddress": '0xb7c1d99069a4eb582fc04e7e1124794000e7ecbf',
    "oracleAddress": "0x3436c4b4a27b793539844090e271591cbcb0303c",
    "type": "LENDING_POOL",
    "reservesList": {
        "0xbb4cdb9cbd36b01bd1cbaebf2de08d9173bc095c": {
            "createdAt": 1648498798,
            "tToken": "0xb11a912cd93dcffa8b609b4c021e89723ceb7fe8",
            "dToken": "0xe7cdc4e53915d50b74496847eeba7233cae85ce5",
            "id": "binancecoin",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.825,
            "label": "BNB"
        },
        "0xe9e7cea3dedca5984780bafc599bd69add087d56": {
            "createdAt": 1648498798,
            "tToken": "0xaed19dab3cd68e4267aec7b2479b1ed2144ad77f",
            "dToken": "0x24758d41e5aa89f79048076254a3d22927b2e0d4",
            "id": "binance-usd",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.85,
            "label": "BUSD"
        },
        "0x8ac76a51cc950d9822d68b83fe1ad97b32cd580d": {
            "createdAt": 1648498798,
            "tToken": "0xa6fdea1655910c504e974f7f1b520b74be21857b",
            "dToken": "0x8ef780a3e1c266af586315a9ada19dbfc3a1e45c",
            "id": "usd-coin",
            "isNew": True,
            "ltv": 0.8,
            "liquidationThreshold": 0.85,
            "label": "USDC"
        },
        "0x55d398326f99059ff775485246999027b3197955": {
            "createdAt": 1648499218,
            "tToken": "0x5f7f6cb266737b89f7af86b30f03ae94334b83e9",
            "dToken": "0x256b441313e10b7210a6239070c085446a507bd8",
            "ltv": 0.8,
            "id": "tether",
            "isNew": True,
            "liquidationThreshold": 0.85,
            "label": "USDT"
        },
        "0x1af3f329e8be154074d8769d1ffa4ee058b1dbc3": {
            "createdAt": 1648499218,
            "tToken": "0x2c85ebae81b7078cd656b2c6e2d58411cb41d91a",
            "dToken": "0x1cf681fc1df8aef478a675df40e62091b93e0aac",
            "ltv": 0.75,
            "id": "dai",
            "isNew": True,
            "liquidationThreshold": 0.8,
            "label": "DAI"
        },
        "0x0e09fabb73bd3ade0a17ecc321fd13a19e81ce82": {
            "createdAt": 1648499218,
            "tToken": "0xc37079a50611a742a018c39ba1c5ebdd89896334",
            "dToken": "0xc7c7bf1f28d29cea48f4aaaefb7e8c1fb43db200",
            "ltv": 0.5,
            "id": "pancakeswap-token",
            "isNew": True,
            "liquidationThreshold": 0.65,
            "label": "CAKE"
        },
        "0x2170ed0880ac9a755fd29b2688956bd959f933f8": {
            "createdAt": 1648499455,
            "tToken": "0x831f42c8a0892c1a5b7fa3e972b3ce3aa40d676e",
            "dToken": "0x9e06035740ab5ed9f48d8ff8b588056693b83e3a",
            "ltv": 0.8,
            "id": "ethereum",
            "isNew": True,
            "liquidationThreshold": 0.825,
            "label": "ETH"
        },
        "0x7130d2a12b9bcbfae4f2634d864a1ee1ce3ead9c": {
            "createdAt": 1648499455,
            "tToken": "0x204992f7fcbc4c0455d7fec5f712bedd98e7d6d6",
            "dToken": "0x5651565e4f544911f16f9a717d3aceccd29d1bda",
            "ltv": 0.7,
            "id": "binance-bitcoin",
            "isNew": True,
            "liquidationThreshold": 0.75,
            "label": "BTCB"
        },
        "0x14016e85a25aeb13065688cafb43044c2ef86784": {
            "createdAt": 1649678592,
            "tToken": "0xbb5dde96bad874e4ffe000b41fa5e98f0665a4bc",
            "dToken": "0xaeb0ae2b4cf427e6e3ebe14b6b92f8bf2d68dfd4",
            "ltv": 0.8,
            "id": "True-usd",
            "isNew": True,
            "liquidationThreshold": 0.825,
            "label": "TUSD"
        }
    },
    "lastUpdatedAt": 0,
    "intervalUpdate": 900,
    "url": "https://valasfinance.com/markets",
    "disabled": True
}
